@@ -345,12 +345,19 @@ impl BuildContext {
                 artifact,
                 Some(musllinux[0]),
                 &self.target,
+                &self.manifest_path,
                 allow_linking_libpython,
             );
         }
 
         let tag = others.first().or_else(|| musllinux.first()).copied();
-        get_policy_and_libs(artifact, tag, &self.target, allow_linking_libpython)
+        get_policy_and_libs(
+            artifact,
+            tag,
+            &self.target,
+            &self.manifest_path,
+            allow_linking_libpython,
+        )
     }
 
     /// Add library search paths in Cargo target directory rpath when building in editable mode
@@ -617,7 +624,14 @@ impl BuildContext {
                 }
             }
             // FreeBSD
-            (Os::FreeBsd, _)
+            | (Os::FreeBsd, _) => {
+                format!(
+                    "{}_{}_{}",
+                    target.target_os().to_string().to_ascii_lowercase(),
+                    target.get_platform_release()?.to_ascii_lowercase(),
+                    target.target_arch().machine(),
+                )
+            }
             // NetBSD
             | (Os::NetBsd, _)
             // OpenBSD
@@ -717,7 +731,7 @@ impl BuildContext {
             &self.out,
             &self.project_layout.project_root,
             &self.metadata24,
-            &[tag.clone()],
+            std::slice::from_ref(&tag),
             self.excludes(Format::Wheel)?,
             self.compression,
         )?;
@@ -796,7 +810,7 @@ impl BuildContext {
             &self.out,
             &self.project_layout.project_root,
             &self.metadata24,
-            &[tag.clone()],
+            std::slice::from_ref(&tag),
             self.excludes(Format::Wheel)?,
             self.compression,
         )?;
